summaryrefslogtreecommitdiff
path: root/app/workers/reactive_caching_worker.rb
diff options
context:
space:
mode:
Diffstat (limited to 'app/workers/reactive_caching_worker.rb')
-rw-r--r--app/workers/reactive_caching_worker.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/app/workers/reactive_caching_worker.rb b/app/workers/reactive_caching_worker.rb
index bcaeaec5709..716b1de2bf5 100644
--- a/app/workers/reactive_caching_worker.rb
+++ b/app/workers/reactive_caching_worker.rb
@@ -6,11 +6,11 @@ class ReactiveCachingWorker # rubocop:disable Scalability/IdempotentWorker
feature_category_not_owned!
# TODO: The reactive caching worker should be split into
# two different workers, one for latency_sensitive jobs without external dependencies
# and another worker without latency_sensitivity, but with external dependencies
# https://gitlab.com/gitlab-com/gl-infra/scalability/issues/34
# This worker should also have `worker_has_external_dependencies!` enabled
- latency_sensitive_worker!
+ urgency :high
worker_resource_boundary :cpu
def perform(class_name, id, *args)
@@ -6,11 +6,11 @@ class ReactiveCachingWorker # rubocop:disable Scalability/IdempotentWorker
feature_category_not_owned!
# TODO: The reactive caching worker should be split into
- # two different workers, one for latency_sensitive jobs without external dependencies
- # and another worker without latency_sensitivity, but with external dependencies
+ # two different workers, one for high urgency jobs without external dependencies
+ # and another worker without high urgency, but with external dependencies
# https://gitlab.com/gitlab-com/gl-infra/scalability/issues/34
# This worker should also have `worker_has_external_dependencies!` enabled